@@ -5,7 +5,8 @@ typedef unsigned int __u32;
 typedef unsigned long long __u64;
 typedef struct {
         __u8 b[16];
-} uuid_le;
+} guid_t;
+typedef guid_t uuid_le;
 typedef unsigned char uuid_t[16];
 #define UUID_STRING_LEN 36
 #define offsetof(a,b) __builtin_offsetof(a,b)
